Learn R Programming

rvinecopulib (version 1.0.0.1.0)

bicop_dependence: Dependence measures of a bivariate copula

Description

Computes the four corner tail-dependence coefficients or Blomqvist's beta for a bivariate copula distribution.

Usage

tail_dep(object)

blomqvist_beta(object)

Value

tail_dep() returns a 2 by 2 matrix whose rows refer to the lower and upper tail of the first variable and whose columns refer to the lower and upper tail of the second variable. blomqvist_beta() returns a numeric scalar.

Arguments

object

a bicop_dist or fitted bicop object.

Examples

Run this code
cop <- bicop_dist("clayton", 0, 2)
tail_dep(cop)
blomqvist_beta(cop)

Run the code above in your browser using DataLab