- data
a matrix or data.frame with at least two columns, containing the
(pseudo-)observations for the two variables (copula data should have
approximately uniform margins). More columns are required for discrete
models, see Details.
- var_types
variable types, a length d vector; e.g., c("c", "c") for
two continuous variables, or c("c", "d") for first variable continuous
and second discrete.
- family_set
a character vector of families; see bicop() for
additional options.
- structure
an rvine_structure object, namely a compressed
representation of the vine structure, or an object that can be coerced into
one (see rvine_structure() and as_rvine_structure()). The dimension
must be length(pair_copulas[[1]]) + 1; structure = NA performs
automatic selection based on Dissman's algorithm. See Details for partial
selection of the structure.
- par_method
the estimation method for parametric models, either "mle"
for maximum likelihood or "itau" for inversion of Kendall's tau (only
available for one-parameter families and "t").
- nonpar_method
the estimation method for nonparametric models, either
"constant" for the standard transformation estimator, or
"linear"/"quadratic" for the local-likelihood approximations of order
one/two.
- mult
multiplier for the smoothing parameters of nonparametric
families. Values larger than 1 make the estimate more smooth, values less
than 1 less smooth.
- selcrit
criterion for family selection, either "loglik", "aic",
"bic", "mbic". For vinecop() there is the additional option
"mbicv".
- weights
optional vector of weights for each observation.
- psi0
prior probability of a non-independence copula (only used for
selcrit = "mbic" and selcrit = "mbicv").
- presel
whether the family set should be thinned out according to
symmetry characteristics of the data.
- allow_rotations
whether to allow rotations of the copula.
- trunc_lvl
the truncation level of the vine copula; Inf means no
truncation, NA indicates that the truncation level should be selected
automatically by mBICV().
- tree_crit
the criterion for tree selection, one of "tau", "rho",
"hoeffd", "mcor", "cxi", or "joe" for Kendall's \(\tau\),
Spearman's \(\rho\), Hoeffding's \(D\), maximum correlation,
symmetrized Chatterjee's \(\xi\), or logarithm of the partial
correlation, respectively. Alternatively, a function with arguments
data and weights may be supplied. data is a two-column
matrix of pair-copula pseudo-observations. weights contains the
corresponding observation weights, standardized by the backend to sum to
the original number of observations, or numeric(0) when no weights were
supplied. Rows containing missing values or zero weights are removed
before the function is called. The function must return one finite numeric
value; its absolute value is used as the edge strength. Custom functions
always run serially on the calling thread; pair-copula fitting may still use
cores threads.
- threshold
for thresholded vine copulas; NA indicates that the
threshold should be selected automatically by mBICV().
- keep_data
whether the data should be stored (necessary for using
fitted()).
- vinecop_object
a vinecop object to be updated; if provided, only the
parameters are fit; structure and families are kept the same.
- show_trace
logical; whether a trace of the fitting progress should be
printed.
- cores
number of cores to use; if more than 1, estimation of pair
copulas within a tree is done in parallel.
- tree_algorithm
The algorithm for building the spanning
tree ("mst_prim", "mst_kruskal", "random_weighted", or
"random_unweighted") during the tree-wise structure selection.
"mst_prim" and "mst_kruskal" use Prim's and Kruskal's algorithms
respectively to select the maximum spanning tree, maximizing
the sum of the edge weights (i.e., tree_crit).
"random_weighted" and "random_unweighted" use Wilson's
algorithm to generate a random spanning tree, either with probability
proportional to the product of the edge weights (weighted) or
uniformly (unweighted).
- conditioning_set
variable indices or names to place at the end of the
vine order. The resulting model can be sampled conditionally with
rvinecop() by supplying u_cond. Conditioning-aware selection supports
fixed or automatically selected truncation levels and requires an MST tree
algorithm ("mst_prim" or "mst_kruskal").