powered by
Marks a numeric vector as continuous with an atom at zero. The class is preserved when stored in or subset from a data frame and is detected by vine(). Alternatively, use var_types = "zi".
vine()
var_types = "zi"
zero_inflated(x)
x with an additional zero_inflated class.
x
zero_inflated
a numeric vector.